@@ -394,4 +394,28 @@ def already_running(path_pidfile: str = 'pid.txt') -> bool:
 		return True
 	except:
 		save(path_pidfile, str(my_pid))
-	return False
\ No newline at end of file
+	return False
+
+def register_protocol_handler(protocol: str, path: str, link_name: str = None, content_type: str = None) -> None:
+	''' Register a protocol handler in Windows, so that <protocol>:<address> links
+	call command <path> <address>. I.e, `register_protocol_handler('magnet',
+	'C:/Program Files/qBittorrent/qbittorrent.exe', link_name='URL:Magnet link',
+	content_type='application/x-magnet')`. '''
+	from os import name as os_name
+	from elevate import elevate
+	elevate()
+	if os_name == 'nt':
+		assert path not in ('explorer', 'explorer.exe', 'start', 'start.exe'), 'Setting start or explorer as a protocol handler would cause an infinite loop'
+		from winreg import CreateKey, SetValue, SetValueEx, HKEY_CLASSES_ROOT, REG_SZ
+		path = path.replace('/', '\\')
+		key = CreateKey(HKEY_CLASSES_ROOT, protocol)
+		if link_name is not None:
+			SetValue(key, None, REG_SZ, link_name)
+		if content_type is not None:
+			SetValueEx(key, 'Content Type', 0, REG_SZ, content_type)
+		SetValueEx(key, 'URL Protocol', 0, REG_SZ, '')
+		SetValue(CreateKey(key, 'DefaultIcon'), None, REG_SZ, '"%s",1' % path)
+		SetValue(CreateKey(key, 'shell'), None, REG_SZ, 'open')
+		SetValue(CreateKey(key, 'shell\\open\\command'), None, REG_SZ, '"%s" "%%1"' % path)
+	else:
+		raise NotImplementedError('register_protocol_handler() is not implemented for your OS.')
\ No newline at end of file
